package com.blundell.tutorial.use;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import android.app.Activity;
import android.content.ActivityNotFoundException;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.view.View;
import android.widget.TextView;
import android.widget.Toast;

public class UseTyreCheckerActivity extends Activity {

	private static final String REG = "DG08CTU";
	private static final int MY_REQ_CODE = 56456;
	private TextView detailsTextView;
	private TextView tyresTextView;

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		detailsTextView = (TextView) findViewById(R.id.car_info);
		tyresTextView = (TextView) findViewById(R.id.tyre_info);
	}

	public void onHandoffClick(View v) {
		Intent intent = new Intent(Intent.ACTION_SEARCH);
		intent.setDataAndType(Uri.parse(REG), "text/registration");

		try {
			startActivity(intent);
		} catch (ActivityNotFoundException e) {
			Toast.makeText(this, R.string.app_not_found, Toast.LENGTH_LONG).show();
			intent = new Intent(Intent.ACTION_VIEW);
			intent.setData(Uri.parse("market://details?id=com.blundell.tyrechecker"));
			startActivity(intent);
		}
	}

	public void onRetrieveClick(View v) {
		Intent intent = new Intent(Intent.ACTION_GET_CONTENT);
		intent.setDataAndType(Uri.parse(REG), "text/registration");
		try {
			startActivityForResult(intent, MY_REQ_CODE);
		} catch (ActivityNotFoundException e) {
			Toast.makeText(this, R.string.app_not_found, Toast.LENGTH_LONG).show();
			intent = new Intent(Intent.ACTION_VIEW);
			intent.setData(Uri.parse("market://details?id=com.blundell.tyrechecker"));
			startActivity(intent);
		}
	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);
		if (requestCode == MY_REQ_CODE) {
			if (resultCode == RESULT_OK) {
				try {
					String jsonString = data.getStringExtra("TyreChecker_Car");
					JSONObject jsonCar = new JSONObject(jsonString);

					String registrationNumber = jsonCar.getString("RegistrationNumber");
					String make = jsonCar.getString("Make");
					String model = jsonCar.getString("Model");
					String color = jsonCar.getString("Color");
					detailsTextView.setText("Reg: " + registrationNumber + " \nMake: " + make + " \nModel: " + model
							+ " \nColor: " + color);

					// Can loop through this array to get all different sets of tyres for the vehicle
					JSONArray tyreSets = jsonCar.getJSONArray("TyreSets");

					// Can also retreive the RearTyrePsi and the TyreType for this set
					String standardFrontTyrePressure = tyreSets.getJSONObject(0).getString("FrontTyrePsi");

					tyresTextView.setText("Front Tyre Standard PSI:\n" + standardFrontTyrePressure);

				} catch (JSONException e) {
					e.printStackTrace();
				}
			}
		}
	}
}